OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Встроенное сообщение %s",
    "Important mail" : "Важная почта",
    "No message found yet" : "Сообщений ещё нет",
    "Set up an account" : "Настроить учётную запись",
    "Unread mail" : "Непрочитанная почта",
    "Important" : "Важное",
    "Work" : "Работа",
    "Personal" : "Личное",
    "To Do" : "Задачи",
    "Later" : "Позже",
    "Mail" : "Почта",
    "You are reaching your mailbox quota limit for {account_email}" : "Вы достигли предела квоты почтового ящика для {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "В настоящее время вы используете {percentage} места в вашем почтовом ящике. Пожалуйста, освободите место, удалив ненужные электронные письма.",
    "Mail Application" : "Почтовое приложение",
    "Mails" : "Почты",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "Адрес электронной почты отправителя: %1$s отсутствует в адресной книге, но имя отправителя: %2$s есть в адресной книге со следующим адресом электронной почты: %3$s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "Адрес электронной почты отправителя: %1$s отсутствует в адресной книге, но имя отправителя: %2$s есть в адресной книге со следующим адресом электронной почты: %3$s",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "Отправитель использует пользовательский адрес электронной почты: %1$s вместо адреса электронной почты отправителя: %2$s",
    "Sent date is in the future" : "Дата отправки еще в будущем",
    "Some addresses in this message are not matching the link text" : "Некоторые адреса в этом сообщении не соответствуют тексту ссылки.",
    "Reply-To email: %1$s  is different from the sender email: %2$s" : "Ответный адрес электронной почты: %1$s отличается от адреса электронной почты отправителя: %2$s",
    "💌 A mail app for Nextcloud" : "💌 Почта для Nextcloud",
    "Your session has expired. The page will be reloaded." : "Истекло время сеанса работы, страница будет обновлена.",
    "Drafts are saved in:" : "Папка черновиков:",
    "Sent messages are saved in:" : "Папка отправленных писем:",
    "Deleted messages are moved in:" : "Папка для удалённых писем:",
    "Archived messages are moved in:" : "Папка архива писем:",
    "Snoozed messages are moved in:" : "Отложенные сообщения перемещаются в:",
    "Junk messages are saved in:" : "Нежелательные сообщения сохраняются в:",
    "Connecting" : "Подключение",
    "Reconnect Google account" : "Переподключите аккаунт Google",
    "Sign in with Google" : "Войти через Google",
    "Reconnect Microsoft account" : "Переподключите учетную запись Microsoft",
    "Sign in with Microsoft" : "Войти через Microsoft",
    "Save" : "Сохранить",
    "Connect" : "Подключиться",
    "Looking up configuration" : "Поиск конфигурации",
    "Checking mail host connectivity" : "Проверка подключения почтового сервера",
    "Configuration discovery failed. Please use the manual settings" : "Не удалось автоматически настроить конфигурацию, введите параметры вручную.",
    "Password required" : "Требуется аутентификация",
    "Testing authentication" : "Проверка аутентификации",
    "Awaiting user consent" : "Ожидание согласия пользователя",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Аккаунт создан. Следуйте инструкциям во всплывающем окне, чтобы связать свою учетную запись Google",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "Учетная запись создана. Пожалуйста, следуйте инструкциям во всплывающем окне, чтобы связать свою учетную запись Microsoft",
    "Loading account" : "Загрузка аккаунта",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Аккаунт обновлен. Следуйте инструкциям во всплывающем окне, чтобы переподключить свою учетную запись Google",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Учетная запись обновлена. Пожалуйста, следуйте инструкциям во всплывающем окне, чтобы переподключить свою учетную запись Microsoft",
    "Account updated" : "Аккаунт обновлен",
    "IMAP server is not reachable" : "Сервер IMAP недоступен",
    "SMTP server is not reachable" : "SMTP сервер недоступен",
    "IMAP username or password is wrong" : "Имя пользователя или пароль IMAP неверны",
    "SMTP username or password is wrong" : "Неверное имя пользователя или пароль SMTP",
    "IMAP connection failed" : "Не удалось установить соединение IMAP",
    "SMTP connection failed" : "Не удалось установить SMTP соединение",
    "Authorization pop-up closed" : "Всплывающее окно авторизации закрыто",
    "Configuration discovery temporarily not available. Please try again later." : "Обнаружение конфигурации временно недоступно. Пожалуйста, повторите попытку позже.",
    "There was an error while setting up your account" : "При настройке вашей учетной записи произошла ошибка",
    "Auto" : "Автоматически",
    "Name" : "Имя",
    "Mail address" : "Почтовый адрес",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Пожалуйста, укажите адрес в формате name@example.com",
    "Password" : "Пароль",
    "Manual" : "Вручную",
    "IMAP Settings" : "Параметры IMAP",
    "IMAP Host" : "IMAP-сервер",
    "IMAP Security" : "Безопасность IMAP",
    "None" : "Отсутствует",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Порт IMAP",
    "IMAP User" : "Имя пользователя IMAP",
    "IMAP Password" : "Пароль IMAP",
    "SMTP Settings" : "Параметры SMTP",
    "SMTP Host" : "Сервер SMTP",
    "SMTP Security" : "Безопасность SMTP",
    "SMTP Port" : "Порт SMTP",
    "SMTP User" : "Имя пользователя SMTP",
    "SMTP Password" : "Пароль SMTP",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Для настройки учётной записи Google необходимо включить двухфакторную аутентификацию и создать пароль приложения.",
    "Account settings" : "Параметры учётной записи",
    "Aliases" : "Псевдонимы",
    "Alias to S/MIME certificate mapping" : "Сопоставление псевдонима с сертификатом S/MIME",
    "Signature" : "Подпись",
    "A signature is added to the text of new messages and replies." : "Подпись будет добавлена к тексту новых писем и при написании ответов.",
    "Writing mode" : "Режим написания",
    "Preferred writing mode for new messages and replies." : "Предпочтительный режим для создания новых писем и ответов.",
    "Default folders" : "Папки по умолчанию",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Папки, которые будут использоваться для черновиков, отправленных сообщений, удаленных сообщений, архивированных сообщений и нежелательных сообщений.",
    "Automatic trash deletion" : "Автоматическое удаление мусора",
    "Days after which messages in Trash will automatically be deleted:" : "Дни, после которых сообщения в Корзине будут автоматически удаляться:",
    "Autoresponder" : "Автоответчик",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматический ответ на входящие сообщения. Если кто-то отправит вам несколько сообщений, этот автоматический ответ будет отправляться не чаще одного раза в 4 дня.",
    "Filters" : "Фильтры",
    "Mail server" : "Почтовый сервер",
    "Mailbox search" : "Поиск по почтовому ящику",
    "Update alias" : "Обновить псевдоним",
    "Rename alias" : "Переименовать псевдоним",
    "Show update alias form" : "Показать обновления для формы alias",
    "Delete alias" : "Удалить псевдоним",
    "Go back" : "Вернуться назад",
    "Change name" : "Изменить имя",
    "Email address" : "Адрес эл. почты",
    "Add alias" : "Добавить псевдоним",
    "Create alias" : "Создать псевдоним",
    "Cancel" : "Отмена",
    "Search in the body of messages in priority Inbox" : "Поиск в тексте сообщений в приоритетной папке «Входящие»",
    "Activate" : "Активировать",
    "Put my text to the bottom of a reply instead of on top of it." : "Поместить мой текст внизу ответа, а не поверх него.",
    "Mark as important" : "Отметить как важное",
    "Remind about messages that require a reply but received none" : "Напомнить о сообщениях, требующих ответа, но не полученных",
    "Use internal addresses" : "Использовать внутренние адреса",
    "Could not update preference" : "Не удалось обновить свойство",
    "Mail settings" : "Параметры эл. почты",
    "Accounts" : "Учётные записи",
    "Add mail account" : "Добавить учётную запись",
    "Settings for:" : "Настройки для:",
    "General" : "Основные",
    "Layout" : "Расположение",
    "List" : "Список",
    "Vertical split" : "Вертикальное разделение",
    "Horizontal split" : "Горизонтальное разделение",
    "Sorting" : "Сортировка",
    "Newest" : "Более новые",
    "Oldest" : "Более старые",
    "Reply text position" : "Позиция текста ответа",
    "Gravatar settings" : "Настройки Gravatar",
    "Use Gravatar and favicon avatars" : "Использовать значки Gravatar и favicon",
    "Mailto" : "Почтовый адрес",
    "Register as application for mail links" : "Зарегистрировать в качестве приложения для обработки почтовых ссылок",
    "Register" : "Регистрация",
    "Privacy and security" : "Конфиденциальность и безопасность",
    "Data collection consent" : "Согласие на сбор данных",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешить приложению собирать данные о взаимодействии.  Основываясь на этих данных, приложение адаптируется к вашим предпочтениям. Данные будут храниться только локально.",
    "Trusted senders" : "Доверенные отправители",
    "Internal addresses" : "Внутренние адреса",
    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Выделяйте внешние адреса электронной почты, включив эту функцию, управляйте своими внутренними адресами и доменами, чтобы распознанные контакты оставались незамеченными.",
    "S/MIME" : "S/MIME",
    "Manage S/MIME certificates" : "Управление сертификатами S/MIME",
    "Mailvelope" : "Почтовый конверт",
    "Mailvelope is enabled for the current domain!" : "Mailvelope включен для текущего домена!",
    "Looking for a way to encrypt your emails?" : "Необходимо использовать шифрование электронных писем?",
    "Install Mailvelope browser extension by clicking here" : "Установите расширение браузера Mailvelope, нажав здесь",
    "Enable Mailvelope for the current domain" : "Включить почтовый конверт для текущего домена",
    "Assistance features" : "Функции помощи",
    "About" : "О себе",
    "Keyboard shortcuts" : "Сочетания клавиш",
    "Compose new message" : "Создать новое сообщение",
    "Newer message" : "Самое новое сообщение",
    "Older message" : "Самое старое сообщение",
    "Toggle star" : "Переключить отметку звёздочкой",
    "Toggle unread" : "Переключить отметку прочтения",
    "Archive" : "Переместить в архив",
    "Delete" : "Удалить",
    "Search" : "Поиск",
    "Send" : "Отправить",
    "Refresh" : "Обновить",
    "No certificate" : "Нет сертификата",
    "Certificate updated" : "Сертификат обновлен",
    "Could not update certificate" : "Не удалось обновить сертификат",
    "{commonName} - Valid until {expiryDate}" : "{commonName} — истекает {expiryDate}",
    "Select an alias" : "Выберите псевдоним",
    "Select certificates" : "Выбрать сертификаты",
    "Update Certificate" : "Обновить сертификат",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "Сервер не доверяет выбранному сертификату. Возможно, получатели не смогут подтвердить вашу подпись.",
    "Encrypt with S/MIME and send later" : "Зашифруйте с помощью S/MIME и отправьте позже",
    "Encrypt with S/MIME and send" : "Зашифруйте с помощью S/MIME и отправить",
    "Encrypt with Mailvelope and send later" : "Зашифруйте с помощью Mailvelope и отправьте позже",
    "Encrypt with Mailvelope and send" : "Зашифруйте с помощью Mailvelope и отправьте",
    "Send later" : "Отправить позже",
    "Message {id} could not be found" : "Не удалось найти сообщение {id}",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Был выбран вариант «Подписать или зашифровать с помощью S/MIME», но у нас нет сертификата для выбранного псевдонима. Сообщение не будет подписано или зашифровано.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Любое существующее форматирование (например, жирный шрифт, курсив, подчеркивание или встроенные изображения) будет удалено.",
    "Turn off formatting" : "Отключить форматирование",
    "Turn off and remove formatting" : "Отключить и удалить форматирование",
    "Keep formatting" : "Сохранить форматирование",
    "From" : "От",
    "Select account" : "Выбрать аккаунт",
    "To" : "Кому",
    "Select recipient" : "Выберите получателя",
    "Contact or email address …" : "Имя или адрес электронной почты...",
    "Cc" : "Коп",
    "Bcc" : "СкрКоп",
    "Subject" : "Тема",
    "Subject …" : "Тема…",
    "This message came from a noreply address so your reply will probably not be read." : "Это сообщение было отправлено с адреса, не предусматривающего получения ответов. Ваше сообщение, направленное на этот адрес, возможно никогда не будет прочитано.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Следующие получатели не имеют сертификата S/MIME: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "У следующих получателей отсутствуют ключи PGP: {recipients}.",
    "Write message …" : "Напишите сообщение…",
    "Saving draft …" : "Сохранение черновика…",
    "Error saving draft" : "Не удалось сохранить черновик",
    "Draft saved" : "Черновик сохранён",
    "Save draft" : "Сохранить черновик",
    "Discard & close draft" : "Отменить изменения и закрыть черновик",
    "Enable formatting" : "Использовать форматирование",
    "Disable formatting" : "Выключить форматирование",
    "Upload attachment" : "Загрузить файл с ПК",
    "Add attachment from Files" : "Из приложения «Файлы»",
    "Add share link from Files" : "Добавить ссылку для общего доступа из Файлов",
    "Smart picker" : "Умный подборщик",
    "Request a read receipt" : "Запросить подтверждение прочтения",
    "Sign message with S/MIME" : "Подписать сообщение с помощью S/MIME",
    "Encrypt message with S/MIME" : "Зашифровать сообщение с помощью S/MIME",
    "Encrypt message with Mailvelope" : "Зашифровать сообщение при помощи приложения Mailvelope",
    "Send now" : "Отправить сейчас",
    "Tomorrow morning" : "Завтра утром",
    "Tomorrow afternoon" : "Завтра днем",
    "Monday morning" : "В понедельник утром",
    "Custom date and time" : "Настроить дату и время",
    "Enter a date" : "Выберите дату",
    "Choose" : "Выберите",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Размер этого вложения превышает установленный лимит, который равен {size}. Опубликуйте этот файл с доступом по ссылке и перешлите ссылку, вместо отправки файла.","Размер этих вложений превышает установленный лимит, который равен {size}. Опубликуйте эти файлы с доступом по ссылке и перешлите ссылку, вместо отправки файлов.","Размер этих вложений превышает установленный лимит, который равен {size}. Опубликуйте эти файлы с доступом по ссылке и перешлите ссылку, вместо отправки файлов.","Размер этих вложений превышает установленный лимит, который равен {size}. Опубликуйте эти файлы с доступом по ссылке и перешлите ссылку, вместо отправки файлов."],
    "Choose a file to add as attachment" : "Выбрать файл для вложения",
    "Choose a file to share as a link" : "Выберите файл для публикации ссылкой",
    "_{count} attachment_::_{count} attachments_" : ["{count} вложение","{count} вложения","{count} вложений","{count} вложений"],
    "Untitled message" : "Сообщение без названия",
    "Confirm" : "Подтвердить",
    "Tag: {name} deleted" : "Тег: {name} удален",
    "An error occurred, unable to delete the tag." : "Произошла ошибка, не удалось удалить тег.",
    "The tag will be deleted from all messages." : "Тег будет удален из всех сообщений.",
    "Plain text" : "Простой текст",
    "Rich text" : "Текст с форматированием",
    "No messages in this mailbox" : "В этой папке нет сообщений",
    "No messages" : "Нет ни одного сообщения",
    "Blind copy recipients only" : "Только получатели скрытой копии",
    "No subject" : "Без темы",
    "Later today – {timeLocale}" : "Позднее сегодня – {timeLocale}",
    "Set reminder for later today" : "Установить напоминание позднее сегодня",
    "Tomorrow – {timeLocale}" : "Завтра – {timeLocale}",
    "Set reminder for tomorrow" : "Установить напоминание на завтра",
    "This weekend – {timeLocale}" : "Эти выходные – {timeLocale}",
    "Set reminder for this weekend" : "Установить напоминание на эти выходные",
    "Next week – {timeLocale}" : "Следующая неделя – {timeLocale}",
    "Set reminder for next week" : "Установить напоминание на следующую неделю",
    "No trash mailbox configured" : "Папка «Удалённые» не настроена",
    "Could not delete message" : "Не удалось удалить сообщение",
    "Could not archive message" : "Не удалось заархивировать письмо",
    "Draft: " : "Черновик:",
    "Encrypted message" : "Зашифрованное сообщение",
    "This message is unread" : "Это сообщение не прочитано",
    "Unfavorite" : "Убрать из избранного",
    "Favorite" : "В избранное",
    "Unread" : "Непрочитанное",
    "Read" : "Прочитать",
    "Unimportant" : "Снять важность",
    "Mark not spam" : "Пометить как не являющееся спамом",
    "Mark as spam" : "Пометить как спам",
    "Edit tags" : "Изменить метки",
    "Move thread" : "Переместить ветку",
    "Archive thread" : "Архивировать тему",
    "Archive message" : "Архивное сообщение",
    "Delete thread" : "Удалить ветку",
    "Delete message" : "Удалить сообщение",
    "More actions" : "Больше действий",
    "Back" : "Назад",
    "Edit as new message" : "Редактировать как новое сообщение",
    "Create event" : "Создать событие",
    "Create task" : "Создать задачу",
    "Download message" : "Скачать письмо",
    "Load more" : "Загрузить больше",
    "_Mark {number} read_::_Mark {number} read_" : ["Отметить {number} сообщение как прочитанное","Отметить {number} сообщения как прочитанные","Отметить {number} сообщений как прочитанные","Отметить {number} сообщения как прочитанные"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Отметить {number} как непрочитанное","Отметить {number} как непрочитанные","Отметить {number} как непрочитанные","Отметить {number} как непрочитанные"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Отметить {number} сообщение как важное","Отметить {number} сообщения как важные","Отметить {number} сообщений как важные","Отметить {number} сообщения как важные"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Отметить {number} сообщение как неважное","Отметить {number} сообщеня как неважные","Отметить {number} сообщений как неважные","Отметить {number} сообщения как неважные"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Убрать {number} сообщение из избранного","Убрать из избранного {number} сообщения","Убрать из избранного {number} сообщений","Убрать из избранного {number} сообщения"],
    "_Favorite {number}_::_Favorite {number}_" : ["Добавить {number} сообщение в избранное","Добавить {number} сообщения в избранное","Добавить {number} сообщений в избранное","Добавить {number} сообщения в избранное"],
    "_Unselect {number}_::_Unselect {number}_" : ["Отменить выбор {number} сообщения","Отменить выбор {number} сообщений","Отменить выбор {number} сообщений","Отменить выбор {number} сообщений"],
    "_Move {number} thread_::_Move {number} threads_" : ["Переместить {number} ветку","Переместить {number} ветки","Переместить {number} веток","Переместить {number} веток"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Переслать {number} сообщение как вложение","Переслать {number} сообщения как вложение","Переслать {number} сообщений как вложение","Переслать {number} сообщения как вложение"],
    "Report this bug" : "Отправить отчёт об этой ошибке",
    "Event created" : "Событие создано",
    "Could not create event" : "Не удалось создать событие",
    "All day" : "Весь день",
    "Select calendar" : "Выбрать календарь",
    "Description" : "Описание",
    "Create" : "Создать",
    "This event was updated" : "Событие было обновлено",
    "{attendeeName} accepted your invitation" : "Пользователь {attendeeName} принял ваше приглашение",
    "{attendeeName} tentatively accepted your invitation" : "Пользователь {attendeeName} предварительно принял ваше приглашение",
    "{attendeeName} declined your invitation" : "{attendeeName} отклонил ваше приглашение",
    "{attendeeName} reacted to your invitation" : "{attendeeName} отреагировал на ваше приглашение",
    "Failed to save your participation status" : "Не удалось сохранить ваш статус участия",
    "You accepted this invitation" : "Вы приняли приглашение",
    "You tentatively accepted this invitation" : "Вы предварительно приняли это приглашение",
    "You declined this invitation" : "Вы отклонили приглашение",
    "You already reacted to this invitation" : "Вы уже отреагировали на это приглашение",
    "You have been invited to an event" : "Вы были приглашены на мероприятие",
    "This event was cancelled" : "Мероприятие было отменено",
    "Save to" : "Сохранить в",
    "Select" : "Выбрать",
    "Comment" : "Комментарий",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Tentatively accept" : "Предварительно принять",
    "More options" : "Дополнительные параметры",
    "Could not remove internal address {sender}" : "Не удалось удалить внутренний адрес {sender}",
    "Could not add internal address {address}" : "Не удалось добавить внутренний адрес {address}",
    "individual" : "личный",
    "domain" : "домен",
    "Remove" : "Удалить",
    "email" : "эл. почта",
    "Add internal address" : "Добавить внутренний адрес",
    "Add internal email or domain" : "Добавить внутреннюю электронную почту или домен",
    "Itinerary for {type} is not supported yet" : "Маршруты типа {type} пока не поддерживаются",
    "To archive a message please configure an archive mailbox in account settings" : "Чтобы заархивировать сообщение, настройте архивный почтовый ящик в настройках учетной записи.",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Вам не разрешено перемещать это сообщение в архивную папку и/или удалять это сообщение из текущей папки.",
    "Could not open mailbox" : "Невозможно открыть папку",
    "Loading messages …" : "Загрузка сообщений...",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Выполняется индексация сообщений, это займёт некоторое время.",
    "Choose target mailbox" : "Выберите папку",
    "No more submailboxes in here" : "Вложенные папки отсутствуют",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Письма будут автоматически отмечаться важными на основе анализа ваших действий и присвоения метки «Важно». В первое время, возможно, потребуется обучить систему присвоением и удалением меток вручную.",
    "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Здесь будут отображаться отправленные вами сообщения, требующие ответа, но не полученные в течение нескольких дней.",
    "Follow up" : "Следовать за",
    "Follow up info" : "Последующая информация",
    "Important info" : "Важная информация",
    "Other" : "Прочие",
    "Could not send mdn" : "Не удалось отправить уведомление о прочтении",
    "The sender of this message has asked to be notified when you read this message." : "Отправитель этого сообщения запросил подтверждение прочтения.",
    "Notify the sender" : "Уведомить отправителя",
    "You sent a read confirmation to the sender of this message." : "Вы отправили подтверждение отправителю этого сообщения.",
    "Message was snoozed" : "Сообщение было отложено",
    "Could not snooze message" : "Не удалось отложить сообщение.",
    "Message was unsnoozed" : "Сообщение было снято с отложенного просмотра",
    "Could not unsnooze message" : "Не удалось отложить сообщение.",
    "Forward" : "Переслать",
    "Move message" : "Переместить сообщение",
    "Translate" : "Перевести",
    "Forward message as attachment" : "Переслать сообщение вложением",
    "View source" : "Просмотреть исходный текст",
    "Print message" : "Распечатать сообщение",
    "Download thread data for debugging" : "Скачать ветку для отладки",
    "Message body" : "Тело сообщения",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Предупреждение: Подпись S/MIME этого сообщения не проверена. Отправитель может выдавать себя за кого-то другого!",
    "Unnamed" : "Без имени",
    "Embedded message" : "Внедрённое сообщение",
    "Attachment saved to Files" : "Вложение сохранено в Файлах",
    "Attachment could not be saved" : "Вложение не может быть сохранено",
    "calendar imported" : "календарь импортирован",
    "Choose a folder to store the attachment in" : "Выберите каталог для хранения вложений",
    "Import into calendar" : "Импортировать в календарь",
    "Download attachment" : "Скачать вложение",
    "Save to Files" : "Сохранить в файлы",
    "Attachments saved to Files" : "Вложения сохранены в файлах",
    "Error while saving attachments" : "Ошибка при сохранении вложений",
    "View fewer attachments" : "Просмотреть меньше вложений",
    "Choose a folder to store the attachments in" : "Выбрать папку для сохранения вложений",
    "Save all to Files" : "Сохранить все в файлы",
    "Download Zip" : "Скачать в архиве ZIP",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Просмотреть ещё {count} вложение","Просмотреть ещё {count} вложения","Просмотреть остальные вложения ({count})","Просмотреть ещё {count} вложений"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Это сообщение зашифровано с помощью PGP. Установите приложение Mailvelope для расшифровывания. ",
    "The images have been blocked to protect your privacy." : "Загрузка изображений заблокирована в целях конфиденциальности.",
    "Show images" : "Показать изображения",
    "Show images temporarily" : "Показать изображения временно",
    "Always show images from {sender}" : "Всегда показывать изображения от {sender}",
    "Always show images from {domain}" : "Всегда показывать изображения с {domain}",
    "Message frame" : "Рамка сообщения",
    "Quoted text" : "Цитируемый текст",
    "Move" : "Переместить",
    "Moving" : "Выполняется перемещение",
    "Moving thread" : "Перемещение ветки",
    "Moving message" : "Сообщение перемещается",
    "Loading …" : "Загрузка ...",
    "Not supported by the server" : "Функция не поддерживается сервером",
    "{usage} of {limit} used" : "Используется {usage} из {limit}",
    "Remove account" : "Удалить учётную запись",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Учётная запись {email} и сохранённые данные будут удалены из Nextcloud, но сохранятся на исходном почтовом сервере.",
    "Remove {email}" : "Удалить {email}",
    "Provisioned account is disabled" : "Предоставленный аккаунт отключен",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Пожалуйста, войдите в систему, используя пароль, чтобы активировать эту учетную запись. Текущий сеанс использует аутентификацию без пароля, например. Единый вход или WebAuthn.",
    "Quota" : "Квота",
    "Show only subscribed mailboxes" : "Показать только папки из подписки",
    "Add mailbox" : "Добавить папку",
    "Mailbox name" : "Имя почтового ящика",
    "Saving" : "Сохранение",
    "Move up" : "Переместить выше",
    "Move down" : "Переместить ниже",
    "Show all subscribed mailboxes" : "Показать все папки из подписки",
    "Show all mailboxes" : "Показать все папки",
    "Collapse mailboxes" : "Свернуть папки",
    "_{total} message_::_{total} messages_" : ["{total} письмо","{total} письма","{total} писем","{total} письма"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}"],
    "All messages in mailbox will be deleted." : "Все сообщения в почтовом ящике будут удалены.",
    "Clear mailbox {name}" : "Очистить почтовый ящик {name}",
    "Clear mailbox" : "Очистить почтовый ящик",
    "The mailbox and all messages in it will be deleted." : "Папка и все письма в ней будут удалены.",
    "Delete mailbox" : "Удалить папку",
    "Delete mailbox {name}" : "Удалить папку {name}",
    "An error occurred, unable to rename the mailbox." : "Ошибка переименования папки.",
    "Mark all as read" : "Пометить всё как прочитанное",
    "Mark all messages of this mailbox as read" : "Пометить все сообщения в папке как прочитанные",
    "Add submailbox" : "Добавить вложенную папку",
    "Rename" : "Переименовать",
    "Move mailbox" : "Переместить почтовый ящик",
    "Clear cache" : "Очистить кэш",
    "Clear locally cached data, in case there are issues with synchronization." : "Очистить локальный кэш данных в случае проблем с синхронизацией.",
    "Subscribed" : "Подписано",
    "Sync in background" : "Фоновая синхронизация",
    "Outbox" : "Исходящие",
    "New message" : "Создать сообщение",
    "Edit message" : "Редактировать сообщение",
    "Draft" : "Черновик",
    "Reply" : "Ответить",
    "Message saved" : "Сообщение сохранено",
    "Failed to save message" : "Не удалось сохранить сообщение",
    "Failed to save draft" : "Не удалось сохранить черновик",
    "attachment" : "вложение",
    "attached" : "прикрепить",
    "No sent mailbox configured. Please pick one in the account settings." : "Не настроена папка исходящих сообщений. Выберите ее в параметрах учётной записи.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Вы пытаетесь отправить письмо очень большому количеству получателей, указанных в полях «Кому» или «Коп». Для сокрытия адреса эл. почты получателя, укажите его в поле «Скр. коп.».",
    "You mentioned an attachment. Did you forget to add it?" : "Вы упомянули вложение. Вы забыли добавить его?",
    "Message discarded" : "Внесение изменений отменено",
    "Could not discard message" : "Не удалось отменить внесение изменений",
    "Error sending your message" : "Ошибка при отправке вашего сообщения",
    "Retry" : "Попробовать снова",
    "Warning sending your message" : "Предупреждать перед отправкой сообщения",
    "Send anyway" : "Все равно отправить",
    "Autoresponder off" : "Автоответчик выключен",
    "Autoresponder on" : "Автоответчик включен",
    "Autoresponder follows system settings" : "Автоответчик следует системным настройкам",
    "The autoresponder follows your personal absence period settings." : "Автоответчик следует вашим персональным настройкам периода отсутствия.",
    "Edit absence settings" : "Изменить настройки отсутствия",
    "First day" : "Первый день",
    "Last day (optional)" : "Последний день (необязательно)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} будет заменено темой сообщения, на которое вы отвечаете",
    "Message" : "Сообщение",
    "Oh Snap!" : "Ого!",
    "Save autoresponder" : "Сохранить автоответчик",
    "Could not open outbox" : "Не удалось открыть исходящие",
    "Pending or not sent messages will show up here" : "В этой папке будут представлены отложенные и неотправленные сообщения",
    "Could not copy to \"Sent\" mailbox" : "Не удалось скопировать в почтовый ящик «Отправленные»",
    "Mail server error" : "Ошибка почтового сервера",
    "Message could not be sent" : "Сообщение не может быть отправлено",
    "Message deleted" : "Сообщение удалено",
    "Copy to \"Sent\" Mailbox" : "Копировать в почтовый ящик «Отправленные»",
    "Copy to Sent Mailbox" : "Копировать в почтовый ящик «Отправленные»",
    "Phishing email" : "Фишинговое письмо",
    "Hide suspicious links" : "Скрыть подозрительные ссылки",
    "Show suspicious links" : "Показать подозрительные ссылки",
    "link text" : "текст ссылки",
    "Copied email address to clipboard" : "Адрес электронной почты скопирован в буфер обмена.",
    "Could not copy email address to clipboard" : "Не удалось скопировать адрес электронной почты в буфер обмена.",
    "Contacts with this address" : "Контакты с этим адресом",
    "Add to Contact" : "Добавить в контакты",
    "New Contact" : "Новый контакт",
    "Copy to clipboard" : "Копировать в буфер",
    "Contact name …" : "Имя контакта …",
    "Add" : "Добавить",
    "Show less" : "Показывать меньше",
    "Show more" : "Показывать больше",
    "Clear" : "Очистить",
    "Search in mailbox" : "Искать в почтовом ящике",
    "Close" : "Закрыть",
    "Search parameters" : "Параметры поиска",
    "Search subject" : "Тема поиска",
    "Body" : "Тело",
    "Date" : "Дата",
    "Pick a start date" : "Выберите дату начала",
    "Pick an end date" : "Выберите дату окончания",
    "Select senders" : "Выберите отправителей",
    "Select recipients" : "Выберите получателей",
    "Tags" : "Метки",
    "Select tags" : "Выбор меток",
    "Marked as" : "Отмечено как",
    "Has attachments" : "Имеет вложения",
    "Has attachment" : "Имеет вложение",
    "Last 7 days" : "Последние 7 дней",
    "From me" : "От меня",
    "Sieve Port" : "Sieve порт",
    "Custom" : "Свои параметры",
    "Sieve User" : "Sieve пользователь",
    "Sieve Password" : "Sieve пароль",
    "Save sieve settings" : "Сохранить настройки sieve",
    "The syntax seems to be incorrect:" : "Синтаксис кажется неправильным:",
    "Save sieve script" : "Сохранить sieve скрипт",
    "Signature …" : "Подпись...",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Размер вашей подписи превышает 2 МБ. Это может повлиять на производительность вашего редактора.",
    "Save signature" : "Сохранить подпись",
    "Place signature above quoted text" : "Размещать подпись над цитируемым текстом",
    "An error occurred, unable to rename the tag." : "Не удалось переименовать метку.",
    "Edit name or color" : "Отредактируйте название или цвет",
    "Saving new tag name …" : "Сохранение нового названия метки…",
    "Delete tag" : "Удалить метку",
    "Set tag" : "Установить тег",
    "Unset tag" : "Неустановленный тег",
    "Tag name is a hidden system tag" : "Имя тега является скрытым системным тегом",
    "Tag already exists" : "Метка уже существует",
    "Tag name cannot be empty" : "Имя тега не может быть пустым",
    "An error occurred, unable to create the tag." : "Не удалось создать метку.",
    "All" : "Все",
    "Drafts" : "Черновики",
    "Favorites" : "Избранные",
    "Priority inbox" : " Приоритетные входящие",
    "All inboxes" : "Все входящие",
    "Inbox" : "Входящие",
    "Junk" : "Спам",
    "Sent" : "Отправленные",
    "Trash" : "Корзина",
    "Connect OAUTH2 account" : "Подключить учетную запись OAUTH2",
    "Error while sharing file" : "Ошибка сохранения файла",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новое сообщение \nот {from}","%n новых сообщения \nот {from}","%n новых сообщений \nот {from}","%n новых сообщений \nот {from}"],
    "Nextcloud Mail" : "Почта Nextcloud",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Сообщение уже находится в обработке. Если вы продолжите, все несохраненные изменения будут потеряны!",
    "Discard changes" : "Отменить изменения",
    "Discard unsaved changes" : "Отменить несохраненные изменения",
    "Keep editing message" : "Продолжайте редактировать сообщение",
    "Attachments were not copied. Please add them manually." : "Вложения не скопированы, добавьте их вручную.",
    "Could not create snooze mailbox" : "Не удалось создать почтовый ящик для отсрочки",
    "Message sent" : "Сообщение отправлено",
    "Could not send message" : "Не удалось отправить сообщение",
    "Message copied to \"Sent\" mailbox" : "Сообщение скопировано в почтовый ящик «Отправленные»",
    "Could not copy message to \"Sent\" mailbox" : "Не удалось скопировать сообщение в почтовый ящик «Отправленные»",
    "Could not load {tag}{name}{endtag}" : "Не удалось загрузить {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Проблема при загрузке {tag}{name}{endtag}",
    "Could not load your message" : "Ошибка получения вашего сообщения",
    "Could not load the desired message" : "Ошибка получения указанного сообщения",
    "Could not load the message" : "Ошибка получения этого сообщения",
    "Error loading message" : "Ошибка загрузки сообщения",
    "Forwarding to %s" : "Пересылка на %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Нажмите здесь, если не запустилось автоматическое перенаправление в течение нескольких секунд.",
    "Redirect" : "Перенаправление",
    "The link leads to %s" : "Эта ссылка ведёт на %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>",
    "Continue to %s" : "Продолжать %s"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
